1. Bowtie2 index files — Spiker documentation

# 1. Bowtie2 index files

We first download the Reference genome sequences for Human, Mouse, and Drosophila from UCSC. We then build the bowtie2 index files for human + Drosophila and mouse + Drosophila composite genomes (listed in the table below).

# 2. Index files for Human + Drosophila

Composite genome | Download link | Size | md5sum
Human (GRCh37/hg19) + Drosophila (dm6) | GRCh37_dm6.tar.gz | 4.9 GB | 962d0356703462f610cde06e46bde9e4
Human (GRCh38/hg38) + Drosophila (dm6) | GRCh38_dm6.tar.gz | 5.1 GB | efb62dac65aafae0ca8d300525cae7c6

# 3. Index files for Mouse + Drosophila

Composite genome | Download link | Size | md5sum
Mouse (NCBI37/mm9) + Drosophila (dm6) | mm9_dm6.tar.gz | 4.3 GB | 885d11585ed5d407f9f37eafd8fff106
Mouse (GRCm38/mm10) + Drosophila (dm6) | mm10_dm6.tar.gz | 4.5 GB | 751753ff50bb2c228e213a8873e92943
Mouse (GRCm39/mm39) + Drosophila (dm6) | mm39_dm6.tar.gz | 4.5 GB | e1cafa46619ad1a1bfd98e00a635e853

After download, use `md5sum *.tar.gz` (Linux) or `md5 *.tar.gz` (Mac OS X) to verify the file integrity and then use `tar -zxvf *.tar.gz` to uncompress.

Note

Because the Drosophila genome also has the “chrX”, “chrY” and, “chrM”. In the composite genome, the chromosome IDs of Drosophila were modified by adding the prefix “dm6_”.